@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2005, 2007,
-   2009 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001-2002, 2005, 2007, 2009-2012 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,9 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-   MA 02110-1301 USA */
+   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include "mail.h"
 
@@ -113,13 +111,13 @@ reply0 (msgset_t *mspec, mu_message_t msg, void *data)
   else
     compose_header_set (&env, MU_HEADER_SUBJECT, "", COMPOSE_REPLACE);
 
-  fprintf (ofile, "To: %s\n",
+  mu_printf ("To: %s\n",
 	   compose_header_get (&env, MU_HEADER_TO, ""));
   str = compose_header_get (&env, MU_HEADER_CC, NULL);
   if (str)
-    fprintf (ofile, "Cc: %s\n", str);
-  fprintf (ofile, "Subject: %s\n\n",
-	   compose_header_get (&env, MU_HEADER_SUBJECT, ""));
+    mu_printf ("Cc: %s\n", str);
+  mu_printf ("Subject: %s\n\n",
+		    compose_header_get (&env, MU_HEADER_SUBJECT, ""));
   
   make_in_reply_to (&env, msg);
   make_references (&env, msg);
